Your message dated Thu, 02 Nov 2006 06:47:23 -0800
with message-id <[EMAIL PROTECTED]>
and subject line Bug#394853: fixed in sg-utils 1.02-3.1
has caused the attached Bug report to be marked as done.
This means that you claim that the problem has been dealt with.
If this is not the case it is now your responsibility to reopen the
Bug report if necessary, and/or fix the problem forthwith.
(NB: If you are a system administrator and have no idea what I am
talking about this indicates a serious mail system misconfiguration
somewhere. Please contact me immediately.)
Debian bug tracking system administrator
(administrator, Debian Bugs database)
--- Begin Message ---
Package: sg-utils
Version: 1.02-3
Severity: serious
Tags: patch
sg-utils fails to build from source using linux-kernel-headers >=
2.6.18.
> gcc -g -O2 -Wall -D_REENTRANT -c -o llseek.o llseek.c
> llseek.c:44: error: expected declaration specifiers or ‘...’ before ‘_llseek’
> llseek.c:44: error: expected declaration specifiers or ‘...’ before ‘fd’
> llseek.c:44: error: expected declaration specifiers or ‘...’ before
> ‘offset_high
This is due to new syscall usage. A patch is attached.
-Ted
-- System Information:
Debian Release: testing/unstable
APT prefers unstable
APT policy: (500, 'unstable'), (1, 'experimental')
Architecture: i386 (i686)
Shell: /bin/sh linked to /bin/dash
Kernel: Linux 2.6.17-2-k7
Locale: LANG=de_DE.UTF-8, LC_CTYPE=de_DE.UTF-8 (charmap=UTF-8)
diff -ru sg-utils-1.02/llseek.c sg-utils-1.02-new/llseek.c
--- sg-utils-1.02/llseek.c 2000-12-09 09:50:02.000000000 +1000
+++ sg-utils-1.02-new/llseek.c 2006-10-23 22:04:07.000000000 +1000
@@ -24,30 +24,21 @@
#ifdef __linux__
-#ifdef HAVE_LLSEEK
-#include <syscall.h>
-
-#else /* HAVE_LLSEEK */
-
#if defined(__alpha__) || defined(__ia64__)
#define my_llseek lseek
#else
-#include <linux/unistd.h> /* for __NR__llseek */
+#include <sys/syscall.h> /* for SYS__llseek */
-static int _llseek (unsigned int, unsigned long,
- unsigned long, llse_loff_t *, unsigned int);
+#ifdef SYS__llseek
-#ifdef __NR__llseek
-
-static _syscall5(int,_llseek,unsigned int,fd,unsigned long,offset_high,
- unsigned long, offset_low,llse_loff_t *,result,
- unsigned int, origin)
+#define _llseek(fd, offset_high, offset_low, result, origin) \
+ syscall(SYS__llseek, fd, offset_high, offset_low, result, origin)
#else
/* no __NR__llseek on compilation machine - might give it explicitly */
static int _llseek (unsigned int fd, unsigned long oh,
unsigned long ol, llse_loff_t *result,
unsigned int origin) {
@@ -71,8 +62,6 @@
#endif /* __alpha__ */
-#endif /* HAVE_LLSEEK */
-
llse_loff_t llse_llseek (unsigned int fd, llse_loff_t offset,
unsigned int origin)
{
--- End Message ---
--- Begin Message ---
Source: sg-utils
Source-Version: 1.02-3.1
We believe that the bug you reported is fixed in the latest version of
sg-utils, which is due to be installed in the Debian FTP archive:
sg-utils_1.02-3.1.diff.gz
to pool/main/s/sg-utils/sg-utils_1.02-3.1.diff.gz
sg-utils_1.02-3.1.dsc
to pool/main/s/sg-utils/sg-utils_1.02-3.1.dsc
sg-utils_1.02-3.1_i386.deb
to pool/main/s/sg-utils/sg-utils_1.02-3.1_i386.deb
A summary of the changes between this version and the previous one is
attached.
Thank you for reporting the bug, which will now be closed. If you
have further comments please address them to [EMAIL PROTECTED],
and the maintainer will reopen the bug report if appropriate.
Debian distribution maintenance software
pp.
Steinar H. Gunderson <[EMAIL PROTECTED]> (supplier of updated sg-utils package)
(This message was generated automatically at their request; if you
believe that there is a problem with it please contact the archive
administrators by mailing [EMAIL PROTECTED])
-----BEGIN PGP SIGNED MESSAGE-----
Hash: SHA1
Format: 1.7
Date: Thu, 2 Nov 2006 15:14:00 +0100
Source: sg-utils
Binary: sg-utils
Architecture: source i386
Version: 1.02-3.1
Distribution: unstable
Urgency: medium
Maintainer: Eric Schwartz (Skif) <[EMAIL PROTECTED]>
Changed-By: Steinar H. Gunderson <[EMAIL PROTECTED]>
Description:
sg-utils - utilities for working with generic SCSI devices
Closes: 394853
Changes:
sg-utils (1.02-3.1) unstable; urgency=medium
.
* Non-maintainer upload.
* Adapt to new syscall usage; fixes FTBFS with kernels >= 2.6.18, patch
from Ted Percival. (Closes: #394853)
Files:
f46b34cc312834c04a60e13a3b523538 693 admin optional sg-utils_1.02-3.1.dsc
87e7cd20efd6063e19e9489d4f489339 4129 admin optional sg-utils_1.02-3.1.diff.gz
d93976c6a1dd335581b35748f993f875 259526 admin optional
sg-utils_1.02-3.1_i386.deb
-----BEGIN PGP SIGNATURE-----
Version: GnuPG v1.4.5 (GNU/Linux)
iQCVAwUBRUn+B37hqgLJpbVOAQKZRQP/Zc770Mzgpw7hFnR/Z089Py5HKGGVz1Rb
vF29kRi5HVyp/Hqa1kiHVbHpcv0ZQ+WgDPWjqrIFUWw4TyZYUB32Efpi6xE3zhbO
o3eQG5VyogKKMmOlsHgiUVQsFxqnWnTA5k88BTFJurX81MKACptF+LX2tXZgt0/+
PbzyJ3HjzXU=
=o5Yo
-----END PGP SIGNATURE-----
--- End Message ---
@@ -24,30 +24,21 @@
#else
-/* no __NR__llseek on compilation machine - might give it explicitly */
+/* no SYS__llseek on compilation machine - might give it explicitly */
static int _llseek (unsigned int fd, unsigned long oh,
unsigned long ol, llse_loff_t *result,